.. _api_reference:

API Reference
=============

The following gives detailed information about all spharpy functions sorted
according to their modules.

For examples on how to use spharpy refer to the notebooks in the
`examples gallery`_ and the documentation on classes and modules below.


Definitions
-----------

.. toctree::
   :maxdepth: 1

   theory/spherical_harmonic_definition


Classes
-------

.. toctree::
   :maxdepth: 1

   classes/spharpy.spherical_harmonics
   classes/spharpy.audio
   classes/spharpy.coordinates

Modules
-------

.. toctree::
   :maxdepth: 1

   modules/spharpy.beamforming
   modules/spharpy.interpolate
   modules/spharpy.plot
   modules/spharpy.samplings
   modules/spharpy.spatial
   modules/spharpy.special
   modules/spharpy.spherical
   modules/spharpy.transforms


.. _examples gallery: https://pyfar-gallery.readthedocs.io/en/latest/examples_gallery.html
